@@ -141,91 +141,12 @@ https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-en
 and more complete implementation can be found in the enamlx package (https://github.com/frmdstryr/enamlx).
 
 
-which list
-__________
+wish list
+_________
 
 * type and syntax checking, code highlighting and debugging of enaml files within PyCharm.
 * fix freezing of linux/Ubuntu system in debugging of opening/opened PopupViews in PyCharm
-  (killing of java PyCharm process helps).
-* fix strange crashes after intensive usage of app (e.g. after pressing TAB or DOWN ARROW key 15-21 times)::
-
-    * python.exe 3.6.9::
-
-        * Segmentation fault (core dumped)
-        * EnamlMainApp.on_flow_widget_focused() 'focus_item:TUtu' <main_view.ThemeButton object at 0x7f891c0d4a48>
-                                                                                                          hasFocus=True
-            Traceback (most recent call last):
-              File "/home/andi/.pyenv/versions/enaml_env/lib/python3.6/site-packages/enaml/qt/qt_container.py", line 507
-                                                                                                 , in _on_relayout_timer
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/contextlib.py", line 159, in helper
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/contextlib.py", line 63, in __init__
-            NameError: name 'getattr' is not defined
-            Unhandled Python exception
-            Aborted (core dumped)
-
-    * PyCharm 3.6.9 Run and miniconda 3.7 (Run or Debug)::
-
-        * process finished with exit code 139 (interrupted by signal 11: SIGSEGV)
-
-    * PyCharm 3.6.9 Debug::
-
-        *   Fatal Python error: Cannot recover from stack overflow::
-
-            Thread 0x00007f1865ec4700 (most recent call first):
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 299 in wait
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 551 in wait
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd.py", line 144 in _on_run
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/_pydevd_bundle/pydevd_comm.py", line 215
-                                                                                                                  in run
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 916 in _bootstrap_inner
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 884 in _bootstrap
-
-            Thread 0x00007f18666c5700 (most recent call first):
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/_pydevd_bundle/pydevd_comm.py", line 285
-                                                                                                              in _on_run
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/_pydevd_bundle/pydevd_comm.py", line 215
-                                                                                                                  in run
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 916 in _bootstrap_inner
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 884 in _bootstrap
-
-            Thread 0x00007f1866ec6700 (most recent call first):
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 299 in wait
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/queue.py", line 173 in get
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/_pydevd_bundle/pydevd_comm.py", line 360
-                                                                                                              in _on_run
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/_pydevd_bundle/pydevd_comm.py", line 215
-                                                                                                                  in run
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 916 in _bootstrap_inner
-              File "/home/andi/.pyenv/versions/3.6.9/lib/python3.6/threading.py", line 884 in _bootstrap
-
-            Current thread 0x00007f18722bc080 (most recent call first):
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd_file_utils.py", line 545
-                                                                                                              in _is_int
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd_file_utils.py", line 552
-                                                                                                         in is_real_file
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd_file_utils.py", line 568
-                                                                            in get_abs_path_real_path_and_base_from_file
-              File "/home/andi/.pyenv/versions/enaml_env/lib/python3.6/site-packages/enaml/qt/qt_widget.py", line 182
-                                                                                                    in tab_focus_request
-              File "/home/andi/.pyenv/versions/enaml_env/lib/python3.6/site-packages/enaml/qt/qt_widget.py", line 242
-                                                                                                   in focusNextPrevChild
-              File "/home/andi/.pyenv/versions/enaml_env/lib/python3.6/site-packages/enaml/qt/qt_application.py", line
-                                                                                                             48 in start
-              File "/home/andi/src/enaml_lisz/ae/enaml_app/__init__.py", line 134 in _event_loop_start
-              File "/home/andi/src/enaml_lisz/ae/gui_app.py", line 828 in run_app
-              File "/home/andi/src/enaml_lisz/main.py", line 346 in <module>
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/_pydev_imps/_pydev_execfile.py", line 18
-                                                                                                             in execfile
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd.py", line 1438 in _exec
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd.py", line 1431 in run
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd.py", line 2122 in main
-              File "/snap/pycharm-community/192/plugins/python-ce/helpers/pydev/pydevd.py", line 2131 in <module>
-
-            Process finished with exit code 134 (interrupted by signal 6: SIGABRT)
-
-
-- TODO: add unit tests for 100 % coverage.
-
+  (workaround: killing of java PyCharm process).
 """
 from abc import abstractmethod, ABC
 from typing import Any, Dict, List, Optional, Sequence
@@ -234,7 +155,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.0.9'
+__version__ = '0.0.10'
 
 
 FLOW_PATH_ROOT_ID = '<<<root>>>'     #: needed for flow path jumper and for drop onto leave item button
@@ -492,7 +413,7 @@ class LiszDataMixin(ABC):
 
         :param flow_path:       flow path list.
         :param min_len:         minimum length of node ids (flow id keys).
-        :return:
+        :return:                shortened display text from the passed flow path.
         """
         path_nid = None         # suppress Pycharm PyUnboundLocalVariable inspection warning
         shortened_ids = list()
@@ -642,7 +563,7 @@ class LiszDataMixin(ABC):
 
         # toggle selection of current item
         elif key_code == ' ' and flo_key:    # key string 'space' is not in Window.command_keys
-            self.change_flow(id_of_flow('save', 'item', flo_key), toggle_sel=True)
+            self.change_flow(id_of_flow('toggle', 'item_sel', flo_key))
 
         # enter/leave flow in current list
         elif key_code in ('enter', 'right') and flo_key and 'node' in self.item_by_id(flo_key):
@@ -786,6 +707,10 @@ class LiszDataMixin(ABC):
             if 'node' in item:
                 item.pop('sel', None)
                 self.shrink_node_size(item['node'])
+            elif item.get('sel', 1) != 1:
+                item.pop('sel')
+            elif 'sel' in item:
+                item['sel'] = 1     # remove also decimal point and zero (float to int)
 
     def sub_item_ids(self, item_id, node_only, node=None, sub_item_ids=None):
         """ return item names of all items including their sub-node items (if exists).
